!***********************************************************
! HiggsBounds example program for SM + invisible Higgs decay
!
! Adapted for Helmholz Alliance HiggsBounds tutorial 
! by TS and OS, 2012-08-14 
!
!***********************************************************
      program HB_SMinv
      
      implicit none
      
      integer nHzero,nHplus,HBresult,chan,ncombined,i
      real*8 obsratio,mass
      real*8 SMGammaTotal,SMGamma_hgg,Gamma_hgg,SMGamma_h,
     &                SMBR_Hgg,FGMGammaTotal

      real*8 Mh,GammaTotal,g2hjss_s,g2hjss_p,g2hjcc_s,g2hjcc_p,
     &       g2hjbb_s,g2hjbb_p,g2hjtt_s,g2hjtt_p,
     &       g2hjmumu_s,g2hjmumu_p,g2hjtautau_s,g2hjtautau_p,
     &       g2hjWW,g2hjZZ,g2hjZga,g2hjgaga,g2hjgg,g2hjggZ,
     &       g2hjhiZ,BR_hjhihi,BR_hjinvisible

!	  One neutral Higgs boson, no charged Higgs      
      nHzero=1
      nHplus=0
 
!     Initialize HB with the option for both LEP and Hadron results         
      call initialize_HiggsBounds(nHzero,nHplus,'LandH')
!     call initialize_HiggsBounds(nHzero,nHplus,'onlyL')
!     call initialize_HiggsBounds(nHzero,nHplus,'onlyH')

!     Set up output files
      open(20,file='inv-SM-results.dat')
      open(21,file='inv-10-results.dat')
      open(22,file='inv-25-results.dat')
      open(23,file='inv-50-results.dat')
      open(24,file='inv-75-results.dat')
      open(25,file='inv-90-results.dat')

!     Loop over Higgs mass

      do i=50,500,1
        Mh=dble(i)
        SMGammaTotal=SMGamma_h(Mh)

!       The SM width can be < 0 if an illegal value is chosen for Mh
        if(.not. (SMGammaTotal .lt. 0)) then

          call HBinvisible(Mh,0.D0, 20)
          call HBinvisible(Mh,0.1D0, 21)
          call HBinvisible(Mh,0.25D0, 22)
          call HBinvisible(Mh,0.50D0, 23)
          call HBinvisible(Mh,0.75D0, 24)
          call HBinvisible(Mh,0.9D0, 25)

	    endif
      enddo

      call finish_HiggsBounds
      
      close(20)
      close(21)
      close(22)
      close(23)
      close(24)
      close(25)

      end
      
! Runs HB with a certain BR(H -> invisible) and writes the output to 
! a file
      subroutine HBinvisible(Mh,BR, fileid)
      
      implicit none
     
      double precision BR
          
      integer fileid    
      integer HBresult,chan,ncombined
      real*8 obsratio,mass
      real*8 SMGammaTotal,SMGamma_h
      
      real*8 Mh,GammaTotal,g2hjss_s,g2hjss_p,g2hjcc_s,g2hjcc_p,
     &       g2hjbb_s,g2hjbb_p,g2hjtt_s,g2hjtt_p,
     &       g2hjmumu_s,g2hjmumu_p,g2hjtautau_s,g2hjtautau_p,
     &       g2hjWW,g2hjZZ,g2hjZga,g2hjgaga,g2hjgg,g2hjggZ,
     &       g2hjhiZ,BR_hjhihi,BR_hjinvisible


          SMGammaTotal = SMGamma_h(Mh)
	
! Redcued couplings are either 0 or 1 for a SM Higgs (reference)
          g2hjss_s=1d0
          g2hjss_p=0d0
          g2hjcc_s=1d0
          g2hjcc_p=0d0
          g2hjbb_s=1d0
          g2hjbb_p=0d0
          g2hjtt_s=1d0
          g2hjtt_p=0d0         
          g2hjmumu_s=1d0
          g2hjmumu_p=0d0  
          g2hjtautau_s=1d0
          g2hjtautau_p=0d0

          g2hjWW=1d0
          g2hjZZ=1d0
          g2hjZga=1d0
          g2hjgaga=1d0
          g2hjgg=1d0
          g2hjggZ=1d0
          g2hjhiZ=0d0
          BR_hjhihi=0d0

          BR_hjinvisible = BR
          GammaTotal=SMGammaTotal/(1.D0-BR_hjinvisible)
                 
          call HiggsBounds_neutral_input_effC(Mh,GammaTotal,
     &    g2hjss_s,g2hjss_p,g2hjcc_s,g2hjcc_p,g2hjbb_s,g2hjbb_p,
     &    g2hjtt_s,g2hjtt_p,
     &    g2hjmumu_s,g2hjmumu_p,g2hjtautau_s,g2hjtautau_p,
     &    g2hjWW,g2hjZZ,g2hjZga,g2hjgaga,g2hjgg,g2hjggZ,
     &    g2hjhiZ, BR_hjinvisible,BR_hjhihi)

          call run_HiggsBounds(HBresult,chan,obsratio,ncombined)
          write(fileid,*) Mh,HBresult,chan,obsratio
      
      end subroutine